@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2021 The apca Developers
+// Copyright (C) 2019-2022 The apca Developers
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 use num_decimal::Num;
@@ -10,7 +10,9 @@ use crate::api::v2::order::Type;
 use crate::Client;
 use crate::RequestError;
 
-pub async fn order_aapl(client: &Client) -> Result<order::Order, RequestError<order::PostError>> {
+pub(crate) async fn order_aapl(
+  client: &Client,
+) -> Result<order::Order, RequestError<order::PostError>> {
   let request = order::OrderReqInit {
     type_: Type::Limit,
     limit_price: Some(Num::from(1)),
