@@ -1,4 +1,4 @@
-// Copyright (C) 2021 The apca Developers
+// Copyright (C) 2021-2022 The apca Developers
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 use chrono::DateTime;
@@ -48,9 +48,9 @@ pub enum Adjustment {
 }
 
 
-/// A GET request to be issued to the /v2/stocks/{symbol} endpoint.
+/// A GET request to be issued to the /v2/stocks/<symbol>/bars endpoint.
 #[derive(Clone, Debug, PartialEq, Serialize)]
-pub struct BarReq {
+pub struct BarsReq {
   /// The symbol for which to retrieve market data.
   #[serde(skip)]
   pub symbol: String,
@@ -66,19 +66,65 @@ pub struct BarReq {
   /// Filter bars equal to or before this time.
   #[serde(rename = "end")]
   pub end: DateTime<Utc>,
-  /// If provided we will pass a page token to continue where we left off.
-  #[serde(rename = "page_token", skip_serializing_if = "Option::is_none")]
-  pub page_token: Option<String>,
   /// The time frame for the bars.
   #[serde(rename = "timeframe")]
   pub timeframe: TimeFrame,
   /// The adjustment to use (defaults to raw)
   #[serde(rename = "adjustment")]
   pub adjustment: Option<Adjustment>,
+  /// If provided we will pass a page token to continue where we left off.
+  #[serde(rename = "page_token", skip_serializing_if = "Option::is_none")]
+  pub page_token: Option<String>,
 }
 
 
-/// A market data bar as returned by the /v2/stocks/{symbol} endpoint.
+/// A GET request to be issued to the /v2/stocks/<symbol>/bars endpoint.
+// TODO: Remove this alias with the next backwards compatibility
+//       breaking release.
+#[deprecated(note = "use BarReq instead")]
+pub type BarReq = BarsReq;
+
+
+/// A helper for initializing [`BarsReq`] objects.
+#[derive(Clone, Debug, Default, PartialEq)]
+pub struct BarsReqInit {
+  /// See `BarsReq::limit`.
+  pub limit: Option<usize>,
+  /// See `BarsReq::adjustment`.
+  pub adjustment: Option<Adjustment>,
+  /// See `BarsReq::page_token`.
+  pub page_token: Option<String>,
+  #[doc(hidden)]
+  pub _non_exhaustive: (),
+}
+
+impl BarsReqInit {
+  /// Create a [`BarsReq`] from a `BarsReqInit`.
+  #[inline]
+  pub fn init<S>(
+    self,
+    symbol: S,
+    start: DateTime<Utc>,
+    end: DateTime<Utc>,
+    timeframe: TimeFrame,
+  ) -> BarsReq
+  where
+    S: Into<String>,
+  {
+    BarsReq {
+      symbol: symbol.into(),
+      start,
+      end,
+      timeframe,
+      limit: self.limit,
+      adjustment: self.adjustment,
+      page_token: self.page_token,
+    }
+  }
+}
+
+
+/// A market data bar as returned by the /v2/stocks/<symbol>/bars endpoint.
 #[derive(Clone, Debug, Deserialize, PartialEq)]
 #[non_exhaustive]
 pub struct Bar {
@@ -118,8 +164,8 @@ pub struct Bars {
 
 
 Endpoint! {
-  /// The representation of a GET request to the /v2/stocks/{symbol}/bars/ endpoint.
-  pub Get(BarReq),
+  /// The representation of a GET request to the /v2/stocks/<symbol>/bars endpoint.
+  pub Get(BarsReq),
   Ok => Bars, [
     /// The market data was retrieved successfully.
     /* 200 */ OK,
@@ -158,6 +204,7 @@ mod tests {
 
   use crate::api_info::ApiInfo;
   use crate::Client;
+  use crate::RequestError;
 
 
   /// Verify that we can properly parse a reference bar response.
@@ -207,16 +254,8 @@ mod tests {
     let client = Client::new(api_info);
     let start = Utc.ymd(2021, 11, 5).and_hms_milli(0, 0, 0, 0);
     let end = Utc.ymd(2021, 11, 5).and_hms_milli(0, 0, 0, 0);
+    let request = BarsReqInit::default().init("AAPL", start, end, TimeFrame::OneDay);
 
-    let request = BarReq {
-      symbol: "SPY".to_string(),
-      limit: None,
-      start,
-      end,
-      timeframe: TimeFrame::OneDay,
-      page_token: None,
-      adjustment: None,
-    };
     let res = client.issue::<Get>(&request).await.unwrap();
     assert_eq!(res.bars, Vec::new())
   }
@@ -228,15 +267,12 @@ mod tests {
     let client = Client::new(api_info);
     let start = Utc.ymd(2018, 12, 3).and_hms_milli(21, 47, 0, 0);
     let end = Utc.ymd(2018, 12, 6).and_hms_milli(21, 47, 0, 0);
-    let request = BarReq {
-      symbol: "AAPL".to_string(),
+    let request = BarsReqInit {
       limit: Some(2),
-      start,
-      end,
-      timeframe: TimeFrame::OneDay,
-      page_token: None,
-      adjustment: None,
-    };
+      ..Default::default()
+    }
+    .init("AAPL", start, end, TimeFrame::OneDay);
+
     let res = client.issue::<Get>(&request).await.unwrap();
     let bars = res.bars;
 
@@ -268,15 +304,12 @@ mod tests {
     let client = Client::new(api_info);
     let start = Utc.ymd(2018, 12, 3).and_hms_milli(21, 47, 0, 0);
     let end = Utc.ymd(2018, 12, 7).and_hms_milli(21, 47, 0, 0);
-    let mut request = BarReq {
-      symbol: "AAPL".to_string(),
+    let mut request = BarsReqInit {
       limit: Some(2),
-      start,
-      end,
-      timeframe: TimeFrame::OneDay,
-      page_token: None,
-      adjustment: None,
-    };
+      ..Default::default()
+    }
+    .init("AAPL", start, end, TimeFrame::OneDay);
+
     let mut res = client.issue::<Get>(&request).await.unwrap();
     let bars = res.bars;
 
@@ -298,15 +331,12 @@ mod tests {
     let client = Client::new(api_info);
     let start = Utc.ymd(2018, 12, 3).and_hms_milli(21, 47, 0, 0);
     let end = Utc.ymd(2018, 12, 4).and_hms_milli(21, 47, 0, 0);
-    let request = BarReq {
-      symbol: "AAPL".to_string(),
-      limit: None,
-      start,
-      end,
-      timeframe: TimeFrame::OneDay,
-      page_token: None,
+    let request = BarsReqInit {
       adjustment: Some(adjustment),
-    };
+      ..Default::default()
+    }
+    .init("AAPL", start, end, TimeFrame::OneDay);
+
     client.issue::<Get>(&request).await.unwrap()
   }
 
@@ -322,10 +352,10 @@ mod tests {
       bars[0].time,
       DateTime::<Utc>::from_utc(NaiveDateTime::from_timestamp(1543899600, 0), Utc)
     );
-    assert_eq!(bars[0].open, Num::new(175700601, 1000000));
-    assert_eq!(bars[0].close, Num::new(171516791, 1000000));
-    assert_eq!(bars[0].high, Num::new(177049807, 1000000));
-    assert_eq!(bars[0].low, Num::new(5347159, 31250));
+    assert_eq!(bars[0].open.to_u64(), Some(175));
+    assert_eq!(bars[0].close.to_u64(), Some(171));
+    assert_eq!(bars[0].high.to_u64(), Some(176));
+    assert_eq!(bars[0].low.to_u64(), Some(170));
     assert_eq!(bars[0].volume, 41344313);
   }
 
@@ -357,10 +387,32 @@ mod tests {
       bars[0].time,
       DateTime::<Utc>::from_utc(NaiveDateTime::from_timestamp(1543899600, 0), Utc)
     );
-    assert_eq!(bars[0].open, Num::new(878503, 20000));
-    assert_eq!(bars[0].close, Num::new(21439599, 500000));
-    assert_eq!(bars[0].high, Num::new(11065613, 250000));
-    assert_eq!(bars[0].low, Num::new(5347159, 125000));
+    assert_eq!(bars[0].open.to_u64(), Some(43));
+    assert_eq!(bars[0].close.to_u64(), Some(42));
+    assert_eq!(bars[0].high.to_u64(), Some(44));
+    assert_eq!(bars[0].low.to_u64(), Some(42));
     assert_eq!(bars[0].volume, 165377252);
   }
+
+  /// Check that we fail as expected when an invalid page token is
+  /// specified.
+  #[test(tokio::test)]
+  async fn invalid_page_token() {
+    let api_info = ApiInfo::from_env().unwrap();
+    let client = Client::new(api_info);
+
+    let start = Utc.ymd(2018, 12, 3).and_hms_milli(21, 47, 0, 0);
+    let end = Utc.ymd(2018, 12, 7).and_hms_milli(21, 47, 0, 0);
+    let request = BarsReqInit {
+      page_token: Some("123456789abcdefghi".to_string()),
+      ..Default::default()
+    }
+    .init("SPY", start, end, TimeFrame::OneMinute);
+
+    let err = client.issue::<Get>(&request).await.unwrap_err();
+    match err {
+      RequestError::Endpoint(GetError::InvalidArgument(_)) => (),
+      _ => panic!("Received unexpected error: {:?}", err),
+    };
+  }
 }
