@@ -80,6 +80,7 @@ mod private {
 /// A trait representing the source from which to stream real time data.
 pub trait Source: private::Sealed {
   /// Return a textual representation of the source.
+  #[doc(hidden)]
   fn as_str() -> &'static str;
 }
 
@@ -275,6 +276,7 @@ pub struct ApiError {
 /// An enum representing the different messages we may receive over our
 /// websocket channel.
 #[derive(Clone, Debug, PartialEq, Deserialize)]
+#[doc(hidden)]
 #[serde(tag = "T")]
 #[allow(clippy::large_enum_variant)]
 pub enum DataMessage {
@@ -304,6 +306,7 @@ pub enum Data {
 
 /// An enumeration of the supported control messages.
 #[derive(Debug)]
+#[doc(hidden)]
 pub enum ControlMessage {
   /// A control message describing the current list of subscriptions.
   Subscription(MarketData),
@@ -546,8 +549,8 @@ where
 
   /// Unsubscribe from receiving market data for the provided symbols.
   ///
-  /// Subscriptions of market data for symbols other than the ones in
-  /// [`unsubscribe`][Self::unsubscribe] is left untouched.
+  /// Subscriptions of market data for symbols other than the ones
+  /// provide to this function are left untouched.
   pub async fn unsubscribe(
     &mut self,
     unsubscribe: &MarketData,
@@ -581,7 +584,7 @@ pub struct RealtimeData<S> {
   _phantom: PhantomData<S>,
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl<S> Subscribable for RealtimeData<S>
 where
   S: Source,
@@ -630,7 +633,7 @@ where
     let mut stream = stream.fuse();
     let mut subscription = Subscription::new(subscription);
 
-    let connect = subscription.subscription.read().boxed_local().fuse();
+    let connect = subscription.subscription.read().boxed().fuse();
     let message = drive(connect, &mut stream).await.map_err(|result| {
       result
         .map(|result| Error::Json(result.unwrap_err()))
@@ -653,10 +656,7 @@ where
       },
     }
 
-    let authenticate = subscription
-      .authenticate(key_id, secret)
-      .boxed_local()
-      .fuse();
+    let authenticate = subscription.authenticate(key_id, secret).boxed().fuse();
     let () = drive(authenticate, &mut stream).await.map_err(|result| {
       result
         .map(|result| Error::Json(result.unwrap_err()))
